@@ -1,5 +1,5 @@
 package Test::POE::Client::TCP;
-$Test::POE::Client::TCP::VERSION = '1.20';
+$Test::POE::Client::TCP::VERSION = '1.22';
 #ABSTRACT: A POE Component providing TCP client services for test cases
 
 use strict;
@@ -14,7 +14,7 @@ our $GOT_SSL;
 BEGIN {
     eval {
         require POE::Component::SSLify;
-        import POE::Component::SSLify qw( Client_SSLify );
+        import POE::Component::SSLify qw( Client_SSLify SSLify_ContextCreate );
         $GOT_SSL = 1;
     };
 }
@@ -505,7 +505,7 @@ Test::POE::Client::TCP - A POE Component providing TCP client services for test
 
 =head1 VERSION
 
-version 1.20
+version 1.22
 
 =head1 SYNOPSIS
 
